/// <reference types="node" />
import * as SES from '@aws-sdk/client-ses';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { ISESHelper } from './interface';
import { Email } from './email';
/**
 * SES Helper
 */
export declare class SESHelper extends BaseClass implements ISESHelper {
    /**
     * AWS Repository for SES
     */
    private Repository;
    /**
     * Initializes new instance of SESHelper
     * @param logger {ILogger} Injected logger
     * @param repository {SES.SES} Injected Repository. A new repository will be created if not supplied
     * @param options {SES.SESClientConfig} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: SES.SES, options?: SES.SESClientConfig);
    /**
     * Send an email
     * @param subject {string} Subject of email
     * @param toAddresses {string[]} Array of addresses to send to
     * @param fromAddress {string} Address to send from
     * @param body {string | Buffer} HTML body of message
     */
    SendEmailAsync(subject: string, toAddresses: string[], fromAddress: string, body: string | Buffer): Promise<SES.SendEmailResponse>;
    /**
     * Sends an email. Optionally sends with attachments
     * @param emailObject {EmailObject} Parameters to send
     */
    SendEmailWithAttachmentsAsync(emailObject: Email): Promise<SES.SendRawEmailResponse>;
}
